

-- x, y, width, height, color1, distance, color2
function loadInterface(x, y, w, h, color1, d, color2)
	love.graphics.setColor(color1 or getInterfaceColor(), 128) -- 
	love.graphics.rectangle("fill", x, y, w, h) -- top
	if d then
		love.graphics.setColor(color2 or getDefaultColor(), 255) -- 
		love.graphics.rectangle("fill", x + d, y + d, w - (d * 2), h - (d * 2) ) -- top
		
	end
	setInterfaceColorDefault()
end

function getMapWidth()
	return imgw
end

function getMapHeight()
	return imgh
end

function changeMapProperties(increase, w, h) -- to resize the map
	-- whole tile
	if increase and w == nil and h == nil then -- z
		imgw = imgw + (squared / 2) 
		imgh = imgh + (squared / 2) 
	elseif increase == false and w == nil and h == nil then -- x
		if imgw <= squared_min and imgh <= squared_min or imgw <= squared_min or imgh <= squared_min then -- 
			return false
		else
			imgw = imgw - (squared / 2)
			imgh = imgh - (squared / 2) 
		end
	-- just the x
	elseif increase and w == true and h == nil then -- right
		imgw = imgw + squaredx
		imgh = imgh 
	elseif increase == false and w == true and h == nil then -- left 
		if imgw <= squared_min then -- 
			return false
		else
			imgw = imgw - squaredx
			imgh = imgh
		end
	-- just the y
	elseif increase and w == nil and h == true then -- down
		imgw = imgw
		imgh = imgh + squaredy 
	elseif increase == false and w == nil and h == true then -- up 
		if imgh <= squared_min then -- 
			return false
		else
			imgw = imgw
			imgh = imgh - squaredy 
		end
	end
	imgdata = setimage(imgw,imgh)
	loadmap(grid, imgdata, 1, 1, imgw, imgh, 0, 0)
	drawGrid(gridlocx, gridlocy, imgdata)
end

function loadMenu(x, y, w, h, text, color) -- not used yet
	love.graphics.setColor(color or getDefaultColor(), 255) -- 
	love.graphics.rectangle("fill", x, y, w, h)
	love.graphics.setColor(0,0,0, 255) -- 
	love.graphics.printf(text, x, y, 0, center)
	setColorDefault()
end


function drawpixel(z, x, y, r, g, b, a)
--print(unpack({z, x, y, r, g, b, a}))
	if pixels[z][x][y] == {r, g, b, a} then --less lag I guess
		return
	end
	imgdata:setPixel(x, y, r, g, b, a)
	loadmap(grid, imgdata, 1, 1, imgw, imgh, 0, 0) -- needs to be here or it won't draw the tiles to screen
	pixels[z][x][y] = {r, g, b, a}
end

function inimage()
	local isin = false
	print("mx "..math.floor(mousex / imgscale).." imgx "..math.floor(imgw * imgscale))
	print("my "..math.floor(mousey / imgscale).. " imgy "..math.floor(imgh * imgscale))
	if mouseRange(0, math.floor(imgw * imgscale), 0, math.floor(imgh * imgscale)) then
		isin = true
		--end
	else
		isin = false
	end
	return isin
end


-- make sure the mouse is in the proper range in the min - max x and y
function mouseRange(minx, maxx, miny, maxy)
	if mousex >  minx and mousex <  maxx then 
		if mousey >  miny and mousey <  maxy then
			return true
		end
	end
	return false
end

-- draw default color pallete
function DrawPallete(x, sp, y, w, h, tw, th)
	local width = w or 45
	local height = h or 45
	local t_w = tw or 1
	local t_h = th or 1
	local posx = x or 0
	local posy = y or 405
	local space = sp or 0
	colorboxw = width
	colorboxh = height
	colory = posy
	colorboxsp = space
	colorx = (width + space) * #colors
	local spaced = width + space
	colorboxx = x or 0
	local t = 0
	for i = 1, #colors do -- colorwheel
		love.graphics.setColor(colors[i], 255)
		love.graphics.rectangle("fill", posx, posy, width, height)
		love.graphics.setColor(255,255,255, 255)
		love.graphics.draw(tile[i], posx+6, posy+6, 0, 1, 1)
		love.graphics.setColor(colors[4], 255)
		love.graphics.rectangle("line", posx, posy, width, height)
		love.graphics.rectangle("line", posx+6, posy+6, math.floor(tile[i]:getWidth() / t_w), math.floor(tile[i]:getHeight() / t_h))
		posx = posx + spaced
	end
	
end

function getPallette(color)
	if mouseRange(colorboxx, colorx, colory, (colory + colorboxh)) then
		for i = 1, #colors do -- loop through all the colors
			if (mousex > colorboxx and mousex < ( ( colorboxw + colorboxsp ) * i) ) then
				if (mousey > colory and mousey < (colory + colorboxh)) then
					return colors[i]
				end
			end
		end
	end
	return colorHolder -- return the old color if we didn't select any colors in the boxes
end

function savetoclipboard(z)
	clipboard[z] = {}
	
	for x = (selection[2][1]-selectionorigin[1])-(selection[2][1]-selectionorigin[1]), selection[2][1]-selectionorigin[1] do
		clipboard[z][x] = {}
		for y = (selection[2][2]-selectionorigin[2])-(selection[2][2]-selectionorigin[2]), selection[2][2]-selectionorigin[2] do
			local r, g, b, a = imgdata:getPixel(x+(selectionorigin[1]), y+(selectionorigin[2]))
			clipboard[z][x][y] = {r, g, b, a}
			print(r .. "-" .. g .. "-" .. b .. "-" .. a)
		end
	end
	pasteready = true
	print("copied")
end

function paste(z, xplus, yplus)
	if clipboard[z] == {} then -- if nothing was or is stored in memory do nothing
		return
	end
	for x = #clipboard[z] - #clipboard[z], #clipboard[z] do
		for y = #clipboard[z][x] - #clipboard[z][x], #clipboard[z][x] do
			if x + xplus <= imgw and y + yplus <= imgh then
				drawpixel(z, x + xplus, y + yplus, unpack(clipboard[z][x][y]))
			end
		end
	end
	print("pasted")
end

function numberPanel(size, x, y, line, fill)
	local font = love.graphics.newFont(size / 2)
	love.graphics.setFont(font) -- might not keep this in here, don't think its a good idea to set the font in a function
	local buttonNumber = {}
	local number = 1
	local space = size / 10
	love.graphics.setColor(fill)
	love.graphics.rectangle("fill", x+size, y, (size * 3) + space, (size * 4) + space)
	love.graphics.setColor(line)
	for i = 1, 3 do -- these for loops create buttons 1- 9
	buttonNumber[i] = {}
		for j = 1, 3 do
			buttonNumber[i][j] = { 
				x = (x + size) * j + space,
				y = y + space,
				w = size,
				h = size, 
				label = {
					text = number,
					x = (x + size) * j + math.floor((x + size) / 3) + space,
					y = y + math.floor(size / 5) + space
				}
			}
			number = number + 1
		end
		y = y + size
	end -- this is for button 0 
	buttonNumber[3][4] = { x = buttonNumber[3][2].x, y = buttonNumber[3][3].y + size, w = size, h = size,
	label = {text = 0, x = buttonNumber[3][2].label.x, y = (buttonNumber[3][3].label.y + size)} 
	}
	for k = 1, 3 do
		for l = 1, 3 do
			love.graphics.rectangle("line", buttonNumber[k][l].x, buttonNumber[k][l].y, buttonNumber[k][l].w-space, buttonNumber[k][l].h-space)
			love.graphics.print(buttonNumber[k][l].label.text, buttonNumber[k][l].label.x, buttonNumber[k][l].label.y)
		end
	end -- this is also for button 0
	love.graphics.rectangle("line", buttonNumber[3][4].x, buttonNumber[3][4].y, buttonNumber[3][4].w-space, buttonNumber[3][4].h-space)
	love.graphics.print(buttonNumber[3][4].label.text, buttonNumber[3][4].label.x, buttonNumber[3][4].label.y)
	setInterfaceColorDefault()
end

function keyboard()
	local index = 0
	for i = 33, 126 do -- create a table of all printable characters
		keyboard[index] = string.char(i)-- will change the index later to letters
		print(keyboard[index])
		index = index + 1
	end
end

function colorWheel(xp, y, w, h) -- needs work
	local x = xp
	local wh = 5
	for i = 0, 32 do
		for j = 0, 32 do
			love.graphics.setColor((j*i), (j*i) * 4, (j*i) * 8)
			love.graphics.rectangle("fill", x, y, wh, wh)
			x = x + wh
		end
		x = xp
		y = y + wh
	end
end


function centerOfATriangle(a,b)
    return math.sqrt((a * a) + (b * b))
 end
 
function setWireFrame(enable)
	love.graphics.setWireframe(enable)

end

function randomTile(tile, range)
	-- will be used by map editor 
end


function tileBorders(borders, mainTile)
	local eight = borders
	local pos = {}
end

