function setimage(imgw, imgh)
	-- create a new tile from thin air
	idata = love.image.newImageData(2, 2)
	if imgdata == nil then -- if there is no map make one
		idata = love.image.newImageData(imgw, imgh)
		for i = 0, imgw-1 do -- the width
			for j = 0, imgh-1 do -- the height
				idata:setPixel(i, j, unpack(MAP_DEFAULT_COLOR))
			end
		end
	else -- if there is, copy the exisiting pixels in the x & y and then paste them into the new map
		idata = love.image.newImageData(imgw, imgh)
		idata = copyAndPastePixels(imgdata, idata)
		
	end
	-- make a map from the newly created tile
	pixels = makeNewMap(pixels, idata, 1, 1, imgw, imgh, 0, 0)

	return idata -- return the newly created map's data
end

function loadmap(pixel_, data, z_min, z_layer, x_width, y_height, w, h)
pixel_t = pixel_ or {}
	for z = z_min, z_layer do
		pixel_t[z] = {} -- z allows us to break up an image into layers
		for x = 0, x_width-1 do
			pixel_t[z][x] = {}
			for y = 0, y_height-1 do
				local r, g, b, a = data:getPixel(x + w, y + h)
				pixel_t[z][x][y] = {r, g, b, a}
				for i = 0, #colors do
				local cr, cg, cb, ca = unpack(colors[i])
				if cr == r and cg == g and cb == b and ca == a then
						pixel_t[z][x][y] = i 
					end
				end
			end
		end
	end
end

function copyAndPastePixels(from, to)
	for x = 0, to:getWidth()-1 do -- get the width of the new map
		for y = 0, to:getHeight()-1 do -- get the height of the new map
			if x > from:getWidth()-1 then -- check if the new map's x is bigger then the source data's width
				to:setPixel(x, y, unpack(MAP_DEFAULT_COLOR)) -- if it is add on the new row in the x using the default color
			elseif y > from:getHeight()-1 then -- check if the new map's y is bigger then the source data's height
				to:setPixel(x, y, unpack(MAP_DEFAULT_COLOR))-- if it is add on the new row in the y using the default color
			else -- if the x & y are within range of the current map
				local r, g, b, a = from:getPixel(x, y) -- copy the current colors at the x & y
				to:setPixel(x, y, r, g, b, a) -- and paste them into the new map :)
			end
		end
	end
	return to -- return the new map with any old data :p
end

function updateGrid(z, x, y, r, g, b, a)
	grid[z][x][y] = {r, g, b, a}
end

function drawGrid(posx, posy, imgd) -- loadMap needs to be called 1st
	for z = 1, #grid do -- uses global grid
		for x = 0, imgd:getWidth()-1 do--#grid[z] do
			for y = 0, imgd:getHeight()-1 do--#grid[z][x] do
			--print("drawGrid z "..z.." y "..y.." x "..x)
				local px = x * size -- lay each tile starting at 0 in the x, stetch it at tile size
				local py = y * size -- lay each tile starting at 0 in the y, stetch it at tile size
				local pz = z -- lay each tile starting at 0 in the y, stetch it at tile size
				for i = 1, #tile do
					if grid[z][x][y] == i then -- draw each tile in the grid in the global x & y plus its local x & y 
				love.graphics.draw(tile[i], posx + (px * scale), posy + (py * scale), rotate, scale, scale)
						--print(tile[i])
					end
				end
			end
		end
	end
end

function getGrid()
	return grid
end

-- create an new map from the given image data
function makeNewMap(pixel_t, data, z_min, z_layer, x_width, y_height, w, h)
	for z = z_min, z_layer do
		pixel_t[z] = {} -- z allows us to break up an image into layers
		for x = 0, x_width-1 do
			pixel_t[z][x] = {}
			for y = 0, y_height-1 do
			--print("makeNewMap z "..z.." y "..y.." x "..x)
				local r, g, b, a = data:getPixel(x + w, y + h)
				pixel_t[z][x][y] = {r, g, b, a}
				map_layer[z_min] = z_min -- what map are we on?
			end
		end
	end
	return pixel_t
end

function drawMapWindow()
--print(#pixels[layer])
	for z = 1, #pixels do
		for x = 0, #pixels[layer] do -- only draw the current layer
			for y = 0, #pixels[layer][x] do
				if ((x * imgscale) + interfaceborder) <= windowwidth and ( (y * imgscale) + interfaceborder) <= 700 then
					love.graphics.setColor(unpack(pixels[layer][x][y])) -- adds color to the image
					love.graphics.rectangle("fill", ((x) * imgscale)+tile_wd, ((y) * imgscale)+tile_yd, imgscale, imgscale) -- draws image
				end
			end
		end
	end
	return false
end

function loadTiles()
	for j = 1, #colors do 
		tile[j] = love.graphics.newImage("tiles/"..j..".png") 
		--print(j)
	end
end


--[[
	to take full advantage of these pixel maps and 3d, we will run tests based on 6 squares where each square (for testing only) has red corners
	where each corner will meet, possibly red center but not needed, although we will work initially with squares of equal length, once that is 
	established we can then use color grades (shades of same color) to determine depth
	
	have to check out eternity warriors for the special effects
	
	add zed within the map function, this way i can generate vox cubes per square and use the characters y as the mouse y rotation and will have the ability to create layers of data per map e.g. collision, minimap, iconic, tile or 3d, normals, bump or enviormental maps. Since my goal enventually is 3d i can easily update the code with little effort, now i can continue on with 2d and finish this aspect of the editor

* update map to handle layers *
* update map swap function to handle switching between layers *	
* update colors to handle blending, blend colors based on layers where each color plus or minus means a different layer, use alpha or gradients to handle this effect, add or remove colors to generate alpha rather then using alpha as alpha, ghost layers to show depth in map editor, don't show the blend in map editor but save the blend in map itself, subtract the color code from the blend per layer, maybe easier to compress and decompress this color blend *

* should be able to mix 3d and 2d planes, isometric? *

need to look at zed and see how and where each side or plane is loaded

have to strip animator and added it to editor, has features ideal, ghost tiles, play and pause, file creation just to name of a few


have alot of work to do to update this editor

]]


function PixelBox(imgw, imgh)
	-- create a new tile from thin air
	spritedata = love.image.newImageData(2, 2)
	if imgdata == nil then -- if there is no map make one
		spritedata = love.image.newImageData(imgw, imgh)
		for i = 0, imgw-1 do -- the width
			for j = 0, imgh-1 do -- the height
				if i == 0 and j == 0 then -- top left corner
					spritedata:setPixel(i, j, {255,0,0,255})
				elseif i == img1-1 and j == 0 then -- top right corner
					spritedata:setPixel(i, j, {255,0,0,255})
				elseif i == 0 and j == imgh-1 then -- bottom left corner
					sprite:setPixel(i, j, {255,0,0,255})
				elseif i == imgw-1 and j == imgh-1 then -- bottom right corner
					spritedata:setPixel(i, j, {255,0,0,255})
				else -- every other position
					spritedata:setPixel(i, j, unpack(MAP_DEFAULT_COLOR))
				end
			end
		end
	else -- if there is, copy the exisiting pixels in the x & y and then paste them into the new map
		--sprite = love.image.newImageData(imgw, imgh)
		--sprite = copyAndPastePixels(imgdata, idata)
	end
	-- make a map from the newly created tile
	--pixels = makeNewMap(pixels, sprite, 1, 1, imgw, imgh, 0, 0)

	return spritedata -- return the newly created map's data
end


